@@ -262,14 +262,26 @@ add_percent_change <- function(data) {
 
 add_technology_share <- function(data) {
   data %>%
-    group_by(.data$sector_ald, .data$year, .data$scenario, .data$name_ald) %>%
+    group_by(
+      .data$sector_ald,
+      .data$year,
+      .data$scenario,
+      .data$name_ald,
+      .data$region
+    ) %>%
     mutate(technology_share = .data$production / sum(.data$production)) %>%
     group_by(!!!dplyr::groups(data))
 }
 
 add_technology_share_target <- function(data) {
   data %>%
-    group_by(.data$sector_ald, .data$year, .data$scenario, .data$name_ald) %>%
+    group_by(
+      .data$sector_ald,
+      .data$year,
+      .data$scenario,
+      .data$name_ald,
+      .data$region
+    ) %>%
     mutate(technology_share_target = .data$production_target / sum(.data$production_target)) %>%
     group_by(!!!dplyr::groups(data))
 }
