@@ -2,7 +2,7 @@ check_no_value_is_missing <- function(data, column) {
   if (anyNA(data[[column]])) {
     abort(
       class = "some_value_is_missing",
-      sprintf("Column `%s` must not contain any `NA`s.", column)
+      glue("Column `{column}` must not contain any `NA`s.")
     )
   }
 
@@ -16,18 +16,14 @@ warn_grouped <- function(data, message) {
 }
 
 # Avoid dependency on purrr
-walk <- function(.x, .f, ...) {
+walk_ <- function(.x, .f, ...) {
   .f <- rlang::as_function(.f)
   lapply(.x, .f, ...)
   invisible(.x)
 }
 
-# We can remove this once we depend on R >= 3.5. See ?backports::isTRUE
-isTRUE <- function(x) {
-  is.logical(x) && length(x) == 1L && !is.na(x) && x
-}
-
-# We can remove this once we depend on R >= 3.5. See ?backports::isFALSE
-isFALSE <- function(x) {
-  is.logical(x) && length(x) == 1L && !is.na(x) && !x
+# Avoid dependency on purrr
+modify_at_ <- function(.x, .at, .f) {
+  .x[[.at]] <- .f(.x[[.at]])
+  .x
 }
